# zoom-deprovisioning-ms

Provides a microservice integration for deprovisioning [University
of Oslo] user accounts from the [Zoom video conferencing] solution.

It listens for messages from the university’s central Identity
Access Governance (IAG) solution and takes action to deprovision
Zoom accounts when accounts are deactivated.  This works by using
[tofh] to listen for messages from [Cerebrum] on [RabbitMQ].  It
verifies event-based information with the [Cerebrum REST API], and
finally communicates with the [Zoom API] to remove user account
access to Zoom.

The software is maintained by the [University Centre for Information
Technology] (USIT).


## Dependencies

If you use a system where the home directory is served over NFS,
as is the default for RHEL workstations at the University of Oslo,
you must select the OverlayFS storage driver explicitly due to a
bug with podman.  Putting the following configuration in
$XDG_CONFIG_HOME/containers/storage.conf is known to work around
this bug on RHEL8:

	[storage]
	  driver="overlay"
	  graphroot = "/var/tmp/<username>/containers/storage"

	  [storage.options.overlay]
	    ignore_chown_errors = "true"
	    mount_program = "/usr/bin/fuse-overlayfs"

You may also experience that your user account does not have
sufficient privileges to use rootless Podman.  This may be because
it is not allocated sufficient sub UIDs in /etc/subuid, see the
[rootless setup user] documentation in Podman.

To be able to deploy the microservice you must first authenticate
yourself with the University’s private image repository, [harbor.uio.no]:

	% podman login -u $(whoami)-drift harbor.uio.no


[Cerebrum REST API]: https://int.usit.uio.no/cerebrum/
[Cerebrum]: https://api-uio.intark.uh-it.no/#!/apis/47b8761b-83e1-421c-b876-1b83e1d21c61/detail
[RabbitMQ]: https://mq-mgmt-uio.blue-apps.intark.uh-it.no/
[University Centre for Information Technology]: https://usit.uio.no/
[University of Oslo]: https://uio.no/
[Zoom API]: https://marketplace.zoom.us/docs/api-reference/zoom-api
[Zoom video conferencing]: https://zoom.us/
[harbor.uio.no]: https://harbor.uio.no/
[rootless setup user]: https://github.com/containers/podman/blob/master/troubleshooting.md#10-rootless-setup-user-invalid-argument
[tofh]: https://bitbucket.usit.uio.no/projects/INT/repos/tofh
