class CerebrumEventException(Exception):
    pass


class CorruptPayload(CerebrumEventException):
    def __init__(self, payload):
        self.payload = payload
        message = "Unable to decode payload"
        super().__init__(message)


class InvalidTimestamp(CerebrumEventException):
    def __init__(self, timestamp):
        self.timestamp = timestamp
        message = f"Invalid timestamp: {timestamp}"
        super().__init__(message)


class InvalidURL(CerebrumEventException):
    def __init__(self, url):
        self.url = url
        message = f"Not a valid URL: {url}"
        super().__init__(message)


class MissingKeys(CerebrumEventException):
    def __init__(self, keys):
        self.keys = keys
        message = "Missing SCIM message entry %s: %s" % (
            "key" if len(keys) == 1 else "keys",
            ", ".join(keys),
        )
        super().__init__(message)
