import logging


log = logging.getLogger(__name__)


class DezoomError(Exception):
    """Base exception for all errors internal to Zoom user deprovisioning."""


class LoggingDezoomError(DezoomError):
    def __init__(self, message, *args, **kwargs):
        super().__init__(message, *args, **kwargs)
        log.exception(self)


class AccountNotFound(LoggingDezoomError):
    """
    Occurs when a Cerebrum account cannot be found.

    This usually indicates a serious problem, as we have been
    notified of a change to the given account, but by the time we
    are processing the notification the account cannot be looked
    up.  This may occur if the message has been delayed in MQ and
    the account has been deleted from the Cerebrum database in the
    mean time.
    """

    def __init__(self, uname: str):
        super().__init__(f"No such account: {uname}")
