import inspect

from logging import (
    Logger,
    LoggerAdapter,
)


class PrefixAdapter(LoggerAdapter):
    def __init__(self, prefix: str, logger: Logger):
        super().__init__(logger, {})
        self.prefix = prefix

    def process(self, msg, kwargs):
        return "%s: %s" % (self.prefix, msg), kwargs


class ScopedLogger(PrefixAdapter):
    """
    Creates a scoped logger that includes the name of the calling function
    and any additional information as a postfix.

    Example::

    	import logging
    	from dezoom.logging import ScopedLogger

    	logger = logging.getLogger(__name__)

    	def foo():
    	    log = ScopedLogger(logger, "bar")
    	    log.info("baz")
    	    # prints "foo: bar: baz")
    """

    def __init__(self, logger: Logger, *postfix: str):
        consumer = inspect.stack()[1].function
        prefix = ": ".join((consumer,) + postfix)
        super().__init__(prefix, logger)
