import logging

from typing import Tuple

from result import Ok, Err, Result

from cerebrum_client.models import Account

from dezoom import Context
from dezoom.lifecycle import inspect


logger = logging.getLogger(__name__)


def extract_username(email: str, wanted_realm: str) -> Result[str, str]:
    if "@" not in email:
        return Err("not an email")
    local, realm = email.split("@")
    if realm != wanted_realm:
        return Err(f"unexpected realm {realm!r}")
    return Ok(local)


def check_all_users(ctx: Context, filename: str):
    assert ctx.destructive is False
    wanted_license_type = ctx.config.dezoom.full_license_type

    import csv

    f = open(filename, "w")
    writer = csv.writer(f)

    def logandprint(*args):
        print(*args)
        writer.writerow(args)

    print("Fetching all users")
    users = []
    count = 0
    for user in ctx.zoom.users.list():
        users.append(user)
        count += 1
        if count % 1000 == 0:
            print("...", count)
    print("Fetched", count, "users")

    for user in users:
        extraction_result = extract_username(user.email, ctx.config.dezoom.realm)
        if not isinstance(extraction_result, Ok):
            logandprint(
                user.id, user.email, user.type.value, extraction_result, "", "ignore"
            )
            continue
        username = extraction_result.value
        account = ctx.cerebrum.get_account(username)
        if account is None:
            logandprint(
                user.id,
                user.email,
                user.type.value,
                "Ok",
                username,
                "ignore, not in cerebrum",
            )
            continue
        fate_fun = inspect(ctx, account)
        fate = fate_fun.__name__
        if fate == "upgrade" and user.type == wanted_license_type:
            fate = "none"
        logandprint(user.id, user.email, user.type.value, "Ok", username, fate)

